@@ -9,7 +9,7 @@ DEFAULT_TEMPLATE_DIR = SOURCE_DIR / "endpoints"
 
 def get_domain():
     ENDPOINT_TEMPLATE_DIR = os.getenv("XEPMTS_ENDPOINT_TEMPLATE_DIR", DEFAULT_TEMPLATE_DIR.absolute())
-    print(ENDPOINT_TEMPLATE_DIR)
+    # print(ENDPOINT_TEMPLATE_DIR)
     ENDPOINT_DIR = os.getenv("XEPMTS_ENDPOINT_DIR", "")
     if not ENDPOINT_DIR:
         templates = read_endpoint_files(ENDPOINT_TEMPLATE_DIR)
